@@ -4,8 +4,9 @@ from dataclasses import dataclass
 
 from django.contrib.admin import site
 from django.contrib.admin.options import BaseModelAdmin
-from django.contrib.admin.utils import flatten_fieldsets
+from django.contrib.admin.utils import flatten_fieldsets, model_format_dict
 from django.contrib.auth.admin import UserAdmin
+from django.core.exceptions import FieldDoesNotExist
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
 from django.db.models.fields.reverse_related import ForeignObjectRel, OneToOneRel
@@ -50,6 +51,14 @@ class OrmModel:
             for (f, l, v) in default_filters
         ]
 
+    def get_queryset(self, request, fields=()):
+        return admin_get_queryset(self.admin, request, fields)
+
+    def do_action(self, request, action, pks):
+        qs = self.get_queryset(request).filter(id__in=pks)
+        func, desc = admin_get_actions(self.admin, request)[action]
+        return func(self.admin, request, qs)
+
 
 def get_model_name(model, sep="."):
     return f"{model._meta.app_label}{sep}{model.__name__}"
@@ -83,6 +92,16 @@ def admin_get_queryset(admin, request, fields=()):
     return admin.get_queryset(request)
 
 
+def admin_get_actions(admin, request):
+    request.data_browser = {"calculated_fields": set(), "fields": set()}
+    res = {}
+    for func, name, desc in admin.get_actions(request).values():
+        if not getattr(func, "ddb_hide", False):
+            desc %= model_format_dict(admin.opts)
+            res[name] = func, desc
+    return res
+
+
 def _get_all_admin_fields(request):
     request.data_browser = {"calculated_fields": set(), "fields": set()}
 
@@ -156,7 +175,12 @@ def _get_all_admin_fields(request):
 
     # we always have id and never pk
     for fields in all_admin_fields.values():
-        fields.add("id")
+        try:
+            model._meta.get_field("id")
+        except FieldDoesNotExist:  # pragma: no cover
+            pass
+        else:
+            fields.add("id")
         fields.discard("pk")
         fields.discard("__str__")
 
@@ -291,7 +315,7 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                 pretty_name=pretty_name,
                 django_field=field,
             )
-        # Calculated and annoted fields
+        # Calculated and annotated fields
         elif isinstance(field, type(None)):
             orm_field = _get_calculated_field(
                 request, field_name, model_name, model, admin, model_fields
@@ -311,6 +335,11 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                         model_name, json_fields
                     )
 
+            if field_name == "id" and hasattr(admin, "get_actions"):
+                actions = admin_get_actions(admin, request)
+            else:
+                actions = {}
+
             fields[field_name] = OrmConcreteField(
                 model_name=model_name,
                 name=field_name,
@@ -318,6 +347,7 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                 type_=field_type,
                 rel_name=rel_name,
                 choices=choices,
+                actions=actions,
             )
     orm_models[model_name] = OrmModel(fields=fields, admin=admin)
     return orm_models
