@@ -76,7 +76,7 @@ _weekday_choices = [
 def _get_django_function(name, qs):
     def IsNull(field_name):
         # https://code.djangoproject.com/ticket/32200
-        if django.VERSION[:3] == (3, 1, 3):
+        if django.VERSION[:3] == (3, 1, 3):  # pragma: django != 3.1.3
             return Subquery(
                 qs.annotate(
                     ddb_is_null=ExpressionWrapper(
@@ -87,7 +87,7 @@ def _get_django_function(name, qs):
                 .values("ddb_is_null")[:1],
                 output_field=BooleanField(),
             )
-        else:  # pragma: django != 3.1.3
+        else:
             return ExpressionWrapper(
                 Q(**{field_name: None}), output_field=BooleanField()
             )
@@ -140,8 +140,8 @@ class OrmBoundFunctionField(OrmBoundField):
         func = _get_django_function(self.name, qs)[0](s(self.previous.queryset_path))
         return qs.annotate(**{s(self.queryset_path): func})
 
-    def parse(self, lookup, value):
-        parsed, err_message = super().parse(lookup, value)
+    def parse_lookup(self, lookup, value):
+        parsed, err_message = super().parse_lookup(lookup, value)
         if self.name in ["year", "iso_year"] and parsed is not None:
             if parsed < 2:
                 err_message = "Can't filter to years less than 2"
