@@ -28,6 +28,7 @@ class QueryFilter:
     value: str
 
     def __post_init__(self):
+        self.path_str = self.path
         self.path = self.path.split("__")
 
 
@@ -47,7 +48,7 @@ class Query:
     limit: int = settings.DATA_BROWSER_DEFAULT_ROW_LIMIT
 
     @classmethod
-    def from_request(cls, model_name, field_str, get_args):
+    def from_request(cls, model_name, field_str, params):
         fields = []
         found_fields = set()
         for field in field_str.split(","):
@@ -76,16 +77,15 @@ class Query:
         limit = settings.DATA_BROWSER_DEFAULT_ROW_LIMIT
 
         filters = []
-        for path__lookup, values in dict(get_args).items():
-            for value in values:
-                if path__lookup == "limit":
-                    try:
-                        limit = max(1, int(value))
-                    except:  # noqa: E722  input sanitization
-                        pass
-                if "__" in path__lookup:
-                    path, lookup = path__lookup.rsplit("__", 1)
-                    filters.append(QueryFilter(path, lookup, value))
+        for path__lookup, value in params:
+            if path__lookup == "limit":
+                try:
+                    limit = max(1, int(value))
+                except:  # noqa: E722  input sanitization
+                    pass
+            if "__" in path__lookup:
+                path, lookup = path__lookup.rsplit("__", 1)
+                filters.append(QueryFilter(path, lookup, value))
 
         return cls(model_name, fields, filters, limit)
 
@@ -121,39 +121,39 @@ class Query:
         return f"{base_url}?{params}"
 
 
-class BoundFieldMixin:
-    @cached_property
-    def path(self):
-        return self.orm_bound_field.full_path
-
-    @cached_property
-    def pretty_path(self):
-        return self.orm_bound_field.pretty_path
-
-    @cached_property
-    def path_str(self):
-        return self.orm_bound_field.path_str
-
-
 @dataclass
-class BoundFilter(BoundFieldMixin):
+class BoundFilter:
     orm_bound_field: Any
     lookup: str
     value: str
+    query_filter: QueryFilter
 
     @classmethod
     def bind(cls, orm_bound_field, query_filter):
-        return cls(orm_bound_field, query_filter.lookup, query_filter.value)
+        return cls(
+            orm_bound_field, query_filter.lookup, query_filter.value, query_filter
+        )
 
     def __post_init__(self):
-        self.parsed, self.err_message = self.orm_bound_field.parse_lookup(
-            self.lookup, self.value
-        )
+        if self.orm_bound_field:
+            self.parsed, self.err_message = self.orm_bound_field.parse_lookup(
+                self.lookup, self.value
+            )
+        else:
+            self.err_message = "Unknown field"
         self.is_valid = not self.err_message
 
+    @cached_property
+    def path(self):
+        return self.query_filter.path
+
+    @cached_property
+    def path_str(self):
+        return self.query_filter.path_str
+
 
 @dataclass
-class BoundField(BoundFieldMixin):
+class BoundField:
     orm_bound_field: Any
     pivoted: bool
     direction: Optional[str]
@@ -168,17 +168,30 @@ class BoundField(BoundFieldMixin):
             query_field.priority if orm_bound_field.concrete else None,
         )
 
+    @cached_property
+    def path(self):
+        return self.orm_bound_field.full_path
+
+    @cached_property
+    def pretty_path(self):
+        return self.orm_bound_field.pretty_path
+
+    @cached_property
+    def path_str(self):
+        return self.orm_bound_field.path_str
+
 
 def _orm_fields(fields):
     return [f.orm_bound_field for f in fields]
 
 
 class BoundQuery:
-    def __init__(self, model_name, fields, filters, limit):
+    def __init__(self, model_name, fields, filters, limit, orm_model):
         self.model_name = model_name
         self.fields = fields
         self.filters = filters
         self.limit = limit
+        self.orm_model = orm_model
 
     @classmethod
     def bind(cls, query, orm_models):
@@ -208,10 +221,11 @@ class BoundQuery:
         filters = []
         for query_filter in query.filters:
             orm_bound_field = get_orm_field(query_filter.path)
-            if orm_bound_field and orm_bound_field.concrete:
-                filters.append(BoundFilter.bind(orm_bound_field, query_filter))
+            if orm_bound_field and not orm_bound_field.concrete:
+                orm_bound_field = None
+            filters.append(BoundFilter.bind(orm_bound_field, query_filter))
 
-        return cls(model_name, fields, filters, query.limit)
+        return cls(model_name, fields, filters, query.limit, orm_models[model_name])
 
     @cached_property
     def sort_fields(self):
