@@ -8,6 +8,7 @@ import pstats
 import sys
 
 import django.contrib.admin.views.decorators as admin_decorators
+import hyperlink
 import sqlparse
 from django import http
 from django.core.serializers.json import DjangoJSONEncoder
@@ -40,6 +41,8 @@ def _get_query_data(bound_query):
         "filterErrors": [filter_.err_message for filter_ in bound_query.filters],
         "parsedFilterValues": [
             filter_.orm_bound_field.get_formatter()(filter_.parsed)
+            if filter_.is_valid
+            else None
             for filter_ in bound_query.filters
         ],
         "fields": [
@@ -72,6 +75,10 @@ def _get_model_fields(model_name, orm_models):
             "prettyName": orm_field.pretty_name,
             "choices": [v for k, v in orm_field.choices],
             "defaultSort": orm_field.default_sort,
+            "actions": [
+                {"name": name, "prettyName": desc}
+                for name, (func, desc) in sorted((orm_field.actions or {}).items())
+            ],
         }
         for name, orm_field in orm_model.fields.items()
     }
@@ -97,7 +104,9 @@ def _get_config(request):
     orm_models = get_models(request)
     types = {
         name: {
-            "lookups": {n: {"type": t} for n, t in type_.lookups.items()},
+            "lookups": {
+                n: {"prettyName": tn, "type": t} for n, (tn, t) in type_.lookups.items()
+            },
             "sortedLookups": list(type_.lookups),
             "defaultLookup": type_.default_lookup,
             "defaultValue": type_.default_value,
@@ -129,9 +138,43 @@ def query_ctx(request, *, model_name="", fields=""):
     return JsonResponse(config)
 
 
+def admin_action(request, model_name, fields):
+    action = request.POST["action"]
+    field = request.POST["field"]
+
+    assert field in fields
+    if field not in fields.split(","):
+        return  # pragma: no cover
+
+    params = hyperlink.parse(request.get_full_path()).query
+    query = Query.from_request(model_name, field, params)
+
+    orm_models = get_models(request)
+    if query.model_name not in orm_models:
+        raise http.Http404(f"{query.model_name} does not exist")  # pragma: no cover
+
+    bound_query = BoundQuery.bind(query, orm_models)
+
+    results = get_results(request, bound_query, orm_models, False)
+
+    pks = {row.get(field) for row in results["rows"]} | {
+        col.get(field) for col in results["cols"]
+    }
+    pks -= {None}
+
+    model_name = bound_query.fields[0].orm_bound_field.field.model_name
+    return orm_models[model_name].do_action(request, action, pks)
+
+
+@csrf.csrf_protect
 @csrf.ensure_csrf_cookie
 @admin_decorators.staff_member_required
 def query_html(request, *, model_name="", fields=""):
+    if request.method == "POST":
+        resp = admin_action(request, model_name, fields)
+        if resp:  # pragma: no branch
+            return resp
+
     config = _get_config(request)
     config = json.dumps(config, cls=DjangoJSONEncoder)
     config = (
@@ -140,7 +183,7 @@ def query_html(request, *, model_name="", fields=""):
 
     if settings.DATA_BROWSER_DEV:  # pragma: no cover
         try:
-            response = _get_from_js_dev_server(request)
+            response = _get_from_js_dev_server(request, "get")
         except Exception as e:
             return HttpResponse(f"Error loading from JS dev server.<br><br>{e}")
 
@@ -153,6 +196,8 @@ def query_html(request, *, model_name="", fields=""):
 
 @admin_decorators.staff_member_required
 def query(request, *, model_name, fields="", media):
+    params = hyperlink.parse(request.get_full_path()).query
+
     if media.startswith("profile") or media.startswith("pstats"):
         if "_" in media:
             prof_media, media = media.split("_")
@@ -164,7 +209,7 @@ def query(request, *, model_name, fields="", media):
         try:
             profiler.enable()
 
-            query = Query.from_request(model_name, fields, request.GET)
+            query = Query.from_request(model_name, fields, params)
             for x in _data_response(request, query, media, privileged=True):
                 pass
 
@@ -192,7 +237,7 @@ def query(request, *, model_name, fields="", media):
             if profiler:  # pragma: no branch
                 profiler.disable()
     else:
-        query = Query.from_request(model_name, fields, request.GET)
+        query = Query.from_request(model_name, fields, params)
         return _data_response(request, query, media, privileged=True)
 
 
@@ -207,7 +252,7 @@ def view(request, pk, media):
     ):
         request.user = view.owner  # public views are run as the person who owns them
         query = view.get_query()
-        return _data_response(request, query, media, privileged=False)
+        return _data_response(request, query, media, privileged=False, strict=True)
     else:
         raise http.Http404("No View matches the given query.")
 
@@ -249,12 +294,15 @@ class Echo:
         return value
 
 
-def _data_response(request, query, media, privileged=False):
+def _data_response(request, query, media, privileged=False, strict=False):
     orm_models = get_models(request)
     if query.model_name not in orm_models:
         raise http.Http404(f"{query.model_name} does not exist")
     bound_query = BoundQuery.bind(query, orm_models)
 
+    if strict and not all(f.is_valid for f in bound_query.filters):
+        return http.HttpResponseBadRequest()
+
     if media == "csv":
         results = get_results(request, bound_query, orm_models, False)
 
@@ -300,7 +348,7 @@ def _data_response(request, query, media, privileged=False):
         resp = _get_query_data(bound_query)
         return JsonResponse(resp)
     elif privileged and media in ["sql", "explain"]:
-        query_set = get_result_queryset(request, bound_query, orm_models)
+        query_set = get_result_queryset(request, bound_query)
         if isinstance(query_set, list):
             res = "Not available for pure aggregates"
         else:
@@ -317,12 +365,14 @@ def _data_response(request, query, media, privileged=False):
         raise http.Http404(f"Bad file format {media} requested")
 
 
-def _get_from_js_dev_server(request):  # pragma: no cover
+def _get_from_js_dev_server(request, method=None):  # pragma: no cover
     import requests
 
+    if method is None:
+        method = request.META["REQUEST_METHOD"].lower()
+
     upstream_url = f"http://127.0.0.1:3000{request.path}"
-    print(f"Proxy request: {upstream_url}")
-    method = request.META["REQUEST_METHOD"].lower()
+    print(f"Proxy request: {method} {upstream_url}")
     return getattr(requests, method)(upstream_url, stream=True)
 
 
