@@ -6,8 +6,8 @@ from django.contrib.admin.options import BaseModelAdmin
 from django.contrib.auth.models import Permission, User
 from django.utils import timezone
 
-from data_browser.orm_admin import OrmModel, get_models
-from data_browser.orm_results import admin_get_queryset, get_results
+from data_browser.orm_admin import OrmModel, admin_get_queryset, get_models
+from data_browser.orm_results import get_results
 from data_browser.query import BoundQuery, Query
 
 from .core import models
@@ -128,18 +128,18 @@ def get_product_pivot(req, orm_models, django_assert_num_queries):
 
 @pytest.mark.usefixtures("products")
 def test_get_results_all(get_product_flat):
-    data = get_product_flat(1, "size-0,name+1,size_unit", {})
+    data = get_product_flat(1, "size-0,name+1,size_unit", [])
     assert data == [[2, "c", "g"], [1, "a", "g"], [1, "b", "g"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_unknown_field(get_product_flat):
-    data = get_product_flat(1, "name+!,fake", {})
+    data = get_product_flat(1, "name+!,fake", [])
     assert data == [["a", "phoney"], ["b", "{}"], ["c", "{}"]]
 
 
 def test_get_admin_link(get_product_flat, products):
-    data = get_product_flat(2, "producer__address__admin", {})
+    data = get_product_flat(2, "producer__address__admin", [])
     sortedAssert(
         data,
         [
@@ -154,7 +154,7 @@ def test_get_file_link(get_product_flat):
     producer = models.Producer.objects.create()
     models.Product.objects.create(name="a", producer=producer)
     models.Product.objects.create(name="b", producer=producer, image="bob.jpg")
-    data = get_product_flat(1, "name,image", {})
+    data = get_product_flat(1, "name,image", [])
     sortedAssert(data, [["a", None], ["b", '<a href="/media/bob.jpg">bob.jpg</a>']])
 
 
@@ -183,33 +183,33 @@ def test_bad_storage(monkeypatch, req):
     producer = models.Producer.objects.create()
     models.Product.objects.create(name="a", producer=producer)
     models.Product.objects.create(name="b", producer=producer, image="bob.jpg")
-    data = get_product_flat("name,image", {})
+    data = get_product_flat("name,image", [])
     sortedAssert(data, [["a", None], ["b", "assert False"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_callable(get_product_flat):
-    data = get_product_flat(2, "name,funky,lambda", {})
+    data = get_product_flat(2, "name,funky,lambda", [])
     sortedAssert(data, [["a", "fa", "la"], ["b", "fb", "lb"], ["c", "fc", "lc"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_calculated_field_on_admin(get_product_flat):
-    data = get_product_flat(2, "producer__address__bob", {})
+    data = get_product_flat(2, "producer__address__bob", [])
     sortedAssert(data, [[None], ["err"], ["bob"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_calculated_boolean_field_on_admin(get_product_flat):
-    data = get_product_flat(2, "calculated_boolean", {})
+    data = get_product_flat(2, "calculated_boolean", [])
     sortedAssert(data, [[True], [True], [True]])
 
 
 def test_get_annotated_field_at_base(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
-    data = get_product_flat(1, "annotated+1,size-2", {"annotated__not_equals": ["a"]})
+    data = get_product_flat(1, "annotated+1,size-2", [("annotated__not_equals", "a")])
     assert data == [["b", 1], ["c", 2]]
     assert len(mock.call_args_list) == 2
 
@@ -217,30 +217,38 @@ def test_get_annotated_field_at_base(products, get_product_flat, mocker):
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_get_aggretated_annotated_field_at_base(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
-    data = get_product_flat(1, "annotated__count+1,size-2", {})
+    data = get_product_flat(1, "annotated__count+1,size-2", [])
     assert data == [[1, 2], [2, 1]]
     assert len(mock.call_args_list) == 2
 
 
+@pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
+def test_filter_and_select_aggregated_annotation(products, get_product_flat):
+    data = get_product_flat(
+        1, "annotated__count+1,size", [("annotated__count__gt", "1")]
+    )
+    assert data == [[2, 1]]
+
+
 def test_get_annotated_field_function_at_base(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
-    data = get_product_flat(1, "annotated__is_null+1,size-2", {})
+    data = get_product_flat(1, "annotated__is_null+1,size-2", [])
     assert data == [["NotNull", 2.0], ["NotNull", 1.0]]
     assert len(mock.call_args_list) == 2
 
 
 def test_get_annotated_field_down_tree(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
     data = get_product_flat(
         1,
         "producer__address__andrew+1,size-2",
-        {"producer__address__andrew__not_equals": ["bad"]},
+        [("producer__address__andrew__not_equals", "bad")],
     )
     assert data == [["good", 1]]
     assert len(mock.call_args_list) == 2
@@ -249,76 +257,76 @@ def test_get_annotated_field_down_tree(products, get_product_flat, mocker):
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_get_aggregated_annotated_field_down_tree(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
-    data = get_product_flat(1, "producer__address__andrew__count+1,size-2", {})
+    data = get_product_flat(1, "producer__address__andrew__count+1,size-2", [])
     assert data == [[0, 2], [2, 1]]
     assert len(mock.call_args_list) == 2
 
 
 def test_get_annotated_field_function_down_tree(products, get_product_flat, mocker):
     mock = mocker.patch(
-        "data_browser.orm_results.admin_get_queryset", wraps=admin_get_queryset
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
     )
-    data = get_product_flat(1, "producer__address__andrew__is_null+1,size-2", {})
+    data = get_product_flat(1, "producer__address__andrew__is_null+1,size-2", [])
     assert data == [["NotNull", 1.0], ["IsNull", 2.0]]
     assert len(mock.call_args_list) == 2
 
 
 @pytest.mark.usefixtures("products")
 def test_get_multiple_calculated_fields_on_admins(get_product_flat):
-    data = get_product_flat(3, "producer__address__bob,producer__frank", {})
+    data = get_product_flat(3, "producer__address__bob,producer__frank", [])
     sortedAssert(data, [[None, "frank"], ["err", "frank"], ["bob", "frank"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_calculated_field(get_product_flat):
-    data = get_product_flat(2, "producer__address__fred", {})
+    data = get_product_flat(2, "producer__address__fred", [])
     sortedAssert(data, [[None], ["bad"], ["fred"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_property(get_product_flat):
-    data = get_product_flat(2, "producer__address__tom", {})
+    data = get_product_flat(2, "producer__address__tom", [])
     sortedAssert(data, [[None], ["bad"], ["tom"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_float_average(get_product_flat):
-    data = get_product_flat(1, "boat__average", {})
+    data = get_product_flat(1, "boat__average", [])
     sortedAssert(data, [[2.3]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_float_sum(get_product_flat):
-    data = get_product_flat(1, "boat__sum", {})
+    data = get_product_flat(1, "boat__sum", [])
     sortedAssert(data, [[4.6]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_time_function(get_product_flat):
-    data = get_product_flat(1, "created_time__year", {})
+    data = get_product_flat(1, "created_time__year", [])
     assert data == [[timezone.now().year]]
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_year_bounds(get_product_flat):
-    data = get_product_flat(1, "size+1", {"created_time__year__equals": ["1"]})
+    data = get_product_flat(1, "size+1", [("created_time__year__equals", "1")])
     assert data == [[1], [2]]  # this errors on the filter and returns all values
 
-    data = get_product_flat(1, "size+1", {"created_time__year__equals": ["2"]})
+    data = get_product_flat(1, "size+1", [("created_time__year__equals", "2")])
     assert data == []
 
-    data = get_product_flat(1, "size+1", {"created_time__year__equals": ["9998"]})
+    data = get_product_flat(1, "size+1", [("created_time__year__equals", "9998")])
     assert data == []
 
-    data = get_product_flat(1, "size+1", {"created_time__year__equals": ["9999"]})
+    data = get_product_flat(1, "size+1", [("created_time__year__equals", "9999")])
     assert data == [[1], [2]]  # this errors on the filter and returns all values
 
 
 @pytest.mark.usefixtures("products")
 def test_get_is_null_function(get_product_flat):
-    data = get_product_flat(1, "name+0,producer__address__city__is_null", {})
+    data = get_product_flat(1, "name+0,producer__address__city__is_null", [])
     assert data == [["a", "NotNull"], ["b", "NotNull"], ["c", "IsNull"]]
 
 
@@ -328,93 +336,93 @@ def test_get_aggregated_is_null_function(get_product_flat):
     models.Product.objects.create(producer=a)
     models.Product.objects.create(producer=b)
     models.Product.objects.create(producer=b)
-    data = get_product_flat(1, "producer__id__is_null,id__count", {})
+    data = get_product_flat(1, "producer__id__is_null,id__count", [])
     assert data == [["NotNull", 3]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_aggregate(get_product_flat):
-    data = get_product_flat(1, "size_unit,id__count", {})
+    data = get_product_flat(1, "size_unit,id__count", [])
     assert data == [["g", 3]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_time_aggregate(get_product_flat):
-    data = get_product_flat(1, "size_unit,created_time__count", {})
+    data = get_product_flat(1, "size_unit,created_time__count", [])
     assert data == [["g", 1]]
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_and_get_aggregate(get_product_flat):
-    data = get_product_flat(1, "size_unit,id__count", {"id__count__gt": [0]})
+    data = get_product_flat(1, "size_unit,id__count", [("id__count__gt", "0")])
     assert data == [["g", 3]]
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_aggregate(get_product_flat):
-    data = get_product_flat(1, "size_unit", {"id__count__gt": [0]})
+    data = get_product_flat(1, "size_unit", [("id__count__gt", "0")])
     assert data == [["g"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_sum_boolean(get_product_flat):
-    data = get_product_flat(1, "size_unit", {"onsale__sum__gt": [100]})
+    data = get_product_flat(1, "size_unit", [("onsale__sum__gt", "100")])
     assert data == []
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_average_boolean(get_product_flat):
-    data = get_product_flat(1, "size_unit", {"onsale__average__gt": [100]})
+    data = get_product_flat(1, "size_unit", [("onsale__average__gt", "100")])
     assert data == []
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_aggregate_no_fields_filter(get_product_flat):
     # no group by -> no having
-    data = get_product_flat(1, "onsale__sum", {"onsale__sum__lt": [0]})
+    data = get_product_flat(1, "onsale__sum", [("onsale__sum__lt", "0")])
     assert data == [[None]]
 
 
 @pytest.mark.usefixtures("products")
 def test_filter_aggregate_no_fields_filter_different(get_product_flat):
     # no group by -> no having
-    data = get_product_flat(1, "onsale__sum", {"onsale__average__lt": [0]})
+    data = get_product_flat(1, "onsale__sum", [("onsale__average__lt", "0")])
     assert data == [[None]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_aggregate_and_calculated_field(get_product_flat):
-    data = get_product_flat(2, "is_onsale,id__count", {})
+    data = get_product_flat(2, "is_onsale,id__count", [])
     sortedAssert(data, [["False", 1], ["False", 1], ["False", 1]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_time_aggregate_and_calculated_field(get_product_flat):
-    data = get_product_flat(2, "is_onsale,created_time__count", {})
+    data = get_product_flat(2, "is_onsale,created_time__count", [])
     sortedAssert(data, [["False", 1], ["False", 1], ["False", 1]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_only_aggregate(get_product_flat):
-    data = get_product_flat(1, "id__count", {})
+    data = get_product_flat(1, "id__count", [])
     assert data == [[3]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_empty(get_product_flat):
-    data = get_product_flat(0, "", {})
+    data = get_product_flat(0, "", [])
     assert data == []
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_sort(get_product_flat):
-    data = get_product_flat(1, "size+0,name-1,size_unit", {})
+    data = get_product_flat(1, "size+0,name-1,size_unit", [])
     assert data == [[1, "b", "g"], [1, "a", "g"], [2, "c", "g"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_pks(get_product_flat):
-    data = get_product_flat(1, "id", {})
+    data = get_product_flat(1, "id", [])
     assert {d[0] for d in data} == set(
         models.Product.objects.values_list("id", flat=True)
     )
@@ -423,85 +431,87 @@ def test_get_results_pks(get_product_flat):
 @pytest.mark.usefixtures("products")
 def test_get_results_calculated_field(get_product_flat):
     # query + prefetch producer
-    data = get_product_flat(2, "name+0,producer__name,is_onsale", {})
+    data = get_product_flat(2, "name+0,producer__name,is_onsale", [])
     assert data == [["a", "Bob", "False"], ["b", "Bob", "False"], ["c", "Bob", "False"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_filtered(get_product_flat):
-    data = get_product_flat(1, "size,name", {"name__equals": ["a"]})
+    data = get_product_flat(1, "size,name", [("name__equals", "a")])
     assert data == [[1, "a"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_excluded(get_product_flat):
-    data = get_product_flat(1, "size-0,name", {"name__not_equals": ["a"]})
+    data = get_product_flat(1, "size-0,name", [("name__not_equals", "a")])
     assert data == [[2, "c"], [1, "b"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_multi_excluded(get_product_flat):
-    data = get_product_flat(1, "size-0,name", {"name__not_equals": ["a", "c"]})
+    data = get_product_flat(
+        1, "size-0,name", [("name__not_equals", "a"), ("name__not_equals", "c")]
+    )
     assert data == [[1, "b"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_collapsed(get_product_flat):
-    data = get_product_flat(1, "size-0,size_unit", {})
+    data = get_product_flat(1, "size-0,size_unit", [])
     assert data == [[2, "g"], [1, "g"]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_null_filter(get_product_flat):
-    data = get_product_flat(1, "name", {"onsale__is_null": ["IsNull"]})
+    data = get_product_flat(1, "name", [("onsale__is_null", "IsNull")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
-    data = get_product_flat(1, "name", {"onsale__is_null": ["NotNull"]})
+    data = get_product_flat(1, "name", [("onsale__is_null", "NotNull")])
     sortedAssert(data, [])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_boolean_filter(get_product_flat):
     models.Product.objects.update(onsale=True)
-    data = get_product_flat(1, "name", {"onsale__equals": ["True"]})
+    data = get_product_flat(1, "name", [("onsale__equals", "True")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
-    data = get_product_flat(1, "name", {"onsale__equals": ["true"]})
+    data = get_product_flat(1, "name", [("onsale__equals", "true")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
-    data = get_product_flat(1, "name", {"onsale__equals": ["False"]})
+    data = get_product_flat(1, "name", [("onsale__equals", "False")])
     sortedAssert(data, [])
-    data = get_product_flat(1, "name", {"onsale__equals": ["false"]})
+    data = get_product_flat(1, "name", [("onsale__equals", "false")])
     sortedAssert(data, [])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_string_filter(get_product_flat):
-    data = get_product_flat(1, "name", {"producer__name__equals": ["Bob"]})
+    data = get_product_flat(1, "name", [("producer__name__equals", "Bob")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
-    data = get_product_flat(1, "name", {"producer__name__equals": ["bob"]})
+    data = get_product_flat(1, "name", [("producer__name__equals", "bob")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
-    data = get_product_flat(1, "name", {"producer__name__equals": ["fred"]})
+    data = get_product_flat(1, "name", [("producer__name__equals", "fred")])
     sortedAssert(data, [])
-    data = get_product_flat(1, "name", {"producer__name__regex": ["\\"]})
+    data = get_product_flat(1, "name", [("producer__name__regex", "\\")])
     sortedAssert(data, [["a"], ["b"], ["c"]])
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_basic_flat(get_product_flat):
     # just a query
-    data = get_product_flat(1, "name+0,producer__address__city", {})
+    data = get_product_flat(1, "name+0,producer__address__city", [])
     assert data == [["a", "london"], ["b", "london"], ["c", None]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_one_to_one(get_product_flat):
     # just a query
-    data = get_product_flat(1, "name+0,producer__address__producer__address__city", {})
+    data = get_product_flat(1, "name+0,producer__address__producer__address__city", [])
     assert data == [["a", "london"], ["b", "london"], ["c", None]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_calculated_causes_query(get_product_flat):
     # query products, fetch objects for calculated
-    data = get_product_flat(2, "name+0,is_onsale,producer__address__city", {})
+    data = get_product_flat(2, "name+0,is_onsale,producer__address__city", [])
     assert data == [
         ["a", "False", "london"],
         ["b", "False", "london"],
@@ -511,7 +521,7 @@ def test_get_results_calculated_causes_query(get_product_flat):
 
 def test_get_results_admin_causes_query(get_product_flat, products):
     # query products, fetch objects for calculated
-    data = get_product_flat(2, "name+0,admin,producer__address__city", {})
+    data = get_product_flat(2, "name+0,admin,producer__address__city", [])
     assert data == [
         ["a", admin_link(products[0]), "london"],
         ["b", admin_link(products[1]), "london"],
@@ -522,7 +532,7 @@ def test_get_results_admin_causes_query(get_product_flat, products):
 @pytest.mark.usefixtures("pivot_products")
 def test_get_pivot(get_product_pivot):
     data = get_product_pivot(
-        3, "created_time__year+0,&created_time__month+1,id__count", {}
+        3, "created_time__year+0,&created_time__month+1,id__count", []
     )
     assert data == {
         "body": [[[1], [3]], [[2], [4]]],
@@ -534,7 +544,7 @@ def test_get_pivot(get_product_pivot):
 @pytest.mark.usefixtures("pivot_products")
 def test_get_pivot_multi_agg(get_product_pivot):
     data = get_product_pivot(
-        3, "created_time__year+0,&created_time__month+1,size__count,size__max", {}
+        3, "created_time__year+0,&created_time__month+1,size__count,size__max", []
     )
     assert data == {
         "body": [[[1, 1], [3, 6]], [[2, 3], [4, 10]]],
@@ -546,7 +556,7 @@ def test_get_pivot_multi_agg(get_product_pivot):
 @pytest.mark.usefixtures("pivot_products")
 def test_get_pivot_all(get_product_pivot):
     data = get_product_pivot(
-        1, "&created_time__year+0, &created_time__month+1,id__count", {}
+        1, "&created_time__year+0, &created_time__month+1,id__count", []
     )
     assert data == {
         "body": [[[1]], [[2]], [[3]], [[4]]],
@@ -576,7 +586,7 @@ def test_pivot_sorting_with_empty_cell(get_product_pivot):
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
 
     data = get_product_pivot(
-        3, "&created_time__year+1,created_time__month+2,id__count", {}
+        3, "&created_time__year+1,created_time__month+2,id__count", []
     )
     assert data == {
         "body": [[[None], [1]], [[2], [3]]],
@@ -585,7 +595,7 @@ def test_pivot_sorting_with_empty_cell(get_product_pivot):
     }
 
     data = get_product_pivot(
-        3, "&created_time__year+2,created_time__month+1,id__count", {}
+        3, "&created_time__year+2,created_time__month+1,id__count", []
     )
     assert data == {
         "body": [[[None], [1]], [[2], [3]]],
@@ -614,7 +624,7 @@ def test_pivot_sorting_body(get_product_pivot):
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
 
     data = get_product_pivot(
-        3, "&created_time__year+1,created_time__month+3,id__count+2", {}
+        3, "&created_time__year+1,created_time__month+3,id__count+2", []
     )
     assert data == {
         "body": [[[1], [3]], [[4], [3]]],
@@ -623,7 +633,7 @@ def test_pivot_sorting_body(get_product_pivot):
     }
 
     data = get_product_pivot(
-        3, "&created_time__year+1,created_time__month+3,id__count-2", {}
+        3, "&created_time__year+1,created_time__month+3,id__count-2", []
     )
     assert data == {
         "body": [[[3], [1]], [[3], [4]]],
@@ -637,7 +647,7 @@ def test_pivot_having(get_product_pivot):
     data = get_product_pivot(
         3,
         "&created_time__year,created_time__month,id__count",
-        {"id__count__equals": [4]},
+        [("id__count__equals", "4")],
     )
     assert data == {"body": [[[4]]], "rows": [["Feburary"]], "cols": [[2021]]}
 
@@ -670,7 +680,7 @@ testdata = [
 @pytest.mark.parametrize("key,rows,cols,body", testdata)
 def test_get_pivot_permutations(get_product_pivot, key, rows, cols, body):
     fields = []
-    filters = {}
+    filters = []
     if "r" in key:  # unpivoted field
         fields.append("created_time__year+0")
     if "c" in key:  # pivoted field
@@ -678,7 +688,7 @@ def test_get_pivot_permutations(get_product_pivot, key, rows, cols, body):
     if "b" in key:  # fields in the body
         fields.extend(["size__count", "size__max"])
     if "d" not in key:  # actually has data
-        filters["id__equals"] = ["-1"]
+        filters.append(("id__equals", "-1"))
 
     queries = 0 if key.endswith("---") else 1
     if "r" in key and "c" in key:
@@ -801,7 +811,7 @@ def test_all_datetime_functions(get_product_flat, lookup, value):
     )
 
     fields = f"created_time__{lookup}" if lookup else "created_time"
-    data = get_product_flat(1, fields, {})
+    data = get_product_flat(1, fields, [])
     assert data == [[value]]
 
 
@@ -817,7 +827,7 @@ def test_all_datetime_functions_2_2(get_product_flat, lookup, value):
     )
 
     fields = f"created_time__{lookup}" if lookup else "created_time"
-    data = get_product_flat(1, fields, {})
+    data = get_product_flat(1, fields, [])
     assert data == [[value]]
 
 
@@ -841,7 +851,7 @@ def test_datetime_aggregations(get_product_flat, aggregation, value):
         producer=producer, created_time=datetime(2020, 1, 3, tzinfo=timezone.utc)
     )
 
-    data = get_product_flat(1, f"created_time__{aggregation}", {})
+    data = get_product_flat(1, f"created_time__{aggregation}", [])
     assert data == [[value]]
 
 
@@ -856,7 +866,7 @@ def test_date_aggregations(get_product_flat, aggregation, value):
     models.Product.objects.create(producer=producer, date=date(2020, 1, 2))
     models.Product.objects.create(producer=producer, date=date(2020, 1, 3))
 
-    data = get_product_flat(1, f"date__{aggregation}", {})
+    data = get_product_flat(1, f"date__{aggregation}", [])
     assert data == [[value]]
 
 
@@ -878,7 +888,7 @@ def test_duration_aggregations(get_product_flat, aggregation, value):
     models.Product.objects.create(producer=producer, duration=timedelta(hours=2))
     models.Product.objects.create(producer=producer, duration=timedelta(hours=3))
 
-    data = get_product_flat(1, f"duration__{aggregation}", {})
+    data = get_product_flat(1, f"duration__{aggregation}", [])
     assert data == [[value]]
 
 
@@ -887,11 +897,11 @@ def test_string_choice_field(get_product_flat):
     models.Product.objects.create(producer=producer, string_choice="a")
     models.Product.objects.create(producer=producer, string_choice="b")
 
-    data = get_product_flat(1, "string_choice", {"string_choice__equals": ["A"]})
+    data = get_product_flat(1, "string_choice", [("string_choice__equals", "A")])
     assert data == [["A"]]
 
     data = get_product_flat(
-        1, "string_choice__raw", {"string_choice__raw__equals": ["a"]}
+        1, "string_choice__raw", [("string_choice__raw__equals", "a")]
     )
     assert data == [["a"]]
 
@@ -901,11 +911,11 @@ def test_number_choice_field(get_product_flat):
     models.Product.objects.create(producer=producer, number_choice=1)
     models.Product.objects.create(producer=producer, number_choice=2)
 
-    data = get_product_flat(1, "number_choice", {"number_choice__equals": ["A"]})
+    data = get_product_flat(1, "number_choice", [("number_choice__equals", "A")])
     assert data == [["A"]]
 
     data = get_product_flat(
-        1, "number_choice__raw", {"number_choice__raw__equals": [1]}
+        1, "number_choice__raw", [("number_choice__raw__equals", "1")]
     )
     assert data == [[1]]
 
@@ -915,17 +925,17 @@ def test_is_null_variants(get_product_flat):
     models.Product.objects.create(producer=producer, size=1, onsale=True)
     models.Product.objects.create(producer=producer, size=2, onsale=None)
 
-    assert get_product_flat(1, "onsale__is_null,size+1", {}) == [
+    assert get_product_flat(1, "onsale__is_null,size+1", []) == [
         ["NotNull", 1],
         ["IsNull", 2],
     ]
 
     # __is_null=
-    assert get_product_flat(1, "size", {"onsale__is_null": ["NotNull"]}) == [[1]]
-    assert get_product_flat(1, "size", {"onsale__is_null": ["IsNull"]}) == [[2]]
+    assert get_product_flat(1, "size", [("onsale__is_null", "NotNull")]) == [[1]]
+    assert get_product_flat(1, "size", [("onsale__is_null", "IsNull")]) == [[2]]
 
     # __is_null__equals=
-    assert get_product_flat(1, "size", {"onsale__is_null__equals": ["NotNull"]}) == [
+    assert get_product_flat(1, "size", [("onsale__is_null__equals", "NotNull")]) == [
         [1]
     ]
-    assert get_product_flat(1, "size", {"onsale__is_null__equals": ["IsNull"]}) == [[2]]
+    assert get_product_flat(1, "size", [("onsale__is_null__equals", "IsNull")]) == [[2]]
